Class: Google::Apis::DeploymentmanagerV2::ListDeploymentsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/deploymentmanager_v2/classes.rb,
lib/google/apis/deploymentmanager_v2/representations.rb,
lib/google/apis/deploymentmanager_v2/representations.rb

Overview

A response containing a partial list of deployments and a page token used to build the next request if the request has been truncated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListDeploymentsResponse

Returns a new instance of ListDeploymentsResponse.



531
532
533
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 531

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deploymentsArray<Google::Apis::DeploymentmanagerV2::Deployment>

Output only. The deployments contained in this response. Corresponds to the JSON property deployments



524
525
526
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 524

def deployments
  @deployments
end

#next_page_tokenString

Output only. A token used to continue a truncated list request. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


529
530
531
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 529

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



536
537
538
539
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 536

def update!(**args)
  @deployments = args[:deployments] if args.key?(:deployments)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end