Class: Google::Apis::DeploymentmanagerV2::Operation::Error::Error

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/deploymentmanager_v2/classes.rb,
lib/google/apis/deploymentmanager_v2/representations.rb,
lib/google/apis/deploymentmanager_v2/representations.rb

Defined Under Namespace

Classes: ErrorDetail

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Error

Returns a new instance of Error.



1324
1325
1326
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1324

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argumentsArray<String>

Output only. [Output Only] Optional error details WARNING: DO NOT MAKE VISIBLE This is for internal use-only (like componentization) (thus the visibility " none") and in case of public exposure it is strongly recommended to follow pattern of: https://aip.dev/193 and expose as details field. Corresponds to the JSON property arguments

Returns:

  • (Array<String>)


1293
1294
1295
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1293

def arguments
  @arguments
end

#codeString

[Output Only] The error type identifier for this error. Corresponds to the JSON property code

Returns:

  • (String)


1298
1299
1300
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1298

def code
  @code
end

#debug_infoGoogle::Apis::DeploymentmanagerV2::DebugInfo

Describes additional debugging info. Corresponds to the JSON property debugInfo



1303
1304
1305
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1303

def debug_info
  @debug_info
end

#error_detailsArray<Google::Apis::DeploymentmanagerV2::Operation::Error::Error::ErrorDetail>

[Output Only] An optional list of messages that contain the error details. There is a set of defined message types to use for providing details.The syntax depends on the error code. For example, QuotaExceededInfo will have details when the error code is QUOTA_EXCEEDED. Corresponds to the JSON property errorDetails



1311
1312
1313
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1311

def error_details
  @error_details
end

#locationString

[Output Only] Indicates the field in the request that caused the error. This property is optional. Corresponds to the JSON property location

Returns:

  • (String)


1317
1318
1319
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1317

def location
  @location
end

#messageString

[Output Only] An optional, human-readable error message. Corresponds to the JSON property message

Returns:

  • (String)


1322
1323
1324
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1322

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1329
1330
1331
1332
1333
1334
1335
1336
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1329

def update!(**args)
  @arguments = args[:arguments] if args.key?(:arguments)
  @code = args[:code] if args.key?(:code)
  @debug_info = args[:debug_info] if args.key?(:debug_info)
  @error_details = args[:error_details] if args.key?(:error_details)
  @location = args[:location] if args.key?(:location)
  @message = args[:message] if args.key?(:message)
end