Class: Google::Apis::DeploymentmanagerV2::SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/deploymentmanager_v2/classes.rb,
lib/google/apis/deploymentmanager_v2/representations.rb,
lib/google/apis/deploymentmanager_v2/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo

Returns a new instance of SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo.



2150
2151
2152
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 2150

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::DeploymentmanagerV2::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



2142
2143
2144
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 2142

def error
  @error
end

#stateString

[Output Only] Status of the action, which can be one of the following: PROPAGATING, PROPAGATED, ABANDONED, FAILED, or DONE. Corresponds to the JSON property state

Returns:

  • (String)


2148
2149
2150
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 2148

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2155
2156
2157
2158
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 2155

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @state = args[:state] if args.key?(:state)
end