Class: Google::Apis::DeploymentmanagerV2::Type

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/deploymentmanager_v2/classes.rb,
lib/google/apis/deploymentmanager_v2/representations.rb,
lib/google/apis/deploymentmanager_v2/representations.rb

Overview

A resource type supported by Deployment Manager.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Type

Returns a new instance of Type.



2305
2306
2307
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 2305

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idFixnum

Corresponds to the JSON property id

Returns:

  • (Fixnum)


2273
2274
2275
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 2273

def id
  @id
end

#insert_timeString

Output only. Creation timestamp in RFC3339 text format. Corresponds to the JSON property insertTime

Returns:

  • (String)


2278
2279
2280
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 2278

def insert_time
  @insert_time
end

#nameString

Name of the type. Corresponds to the JSON property name

Returns:

  • (String)


2283
2284
2285
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 2283

def name
  @name
end

#operationGoogle::Apis::DeploymentmanagerV2::Operation

Represents an Operation resource. Google Compute Engine has three Operation resources: * Global * Regional * Zonal You can use an operation resource to manage asynchronous API requests. For more information, read Handling API responses. Operations can be global, regional or zonal. - For global operations, use the globalOperations resource. - For regional operations, use the regionOperations resource. - For zonal operations, use the zoneOperations resource. For more information, read Global, Regional, and Zonal Resources. Note that completed Operation resources have a limited retention period. Corresponds to the JSON property operation



2298
2299
2300
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 2298

def operation
  @operation
end

Output only. Server defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


2303
2304
2305
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 2303

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2310
2311
2312
2313
2314
2315
2316
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 2310

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @insert_time = args[:insert_time] if args.key?(:insert_time)
  @name = args[:name] if args.key?(:name)
  @operation = args[:operation] if args.key?(:operation)
  @self_link = args[:self_link] if args.key?(:self_link)
end