Class: Google::Apis::DeploymentmanagerV2::Operation
- Inherits:
-
Object
- Object
- Google::Apis::DeploymentmanagerV2::Operation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/deploymentmanager_v2/classes.rb,
lib/google/apis/deploymentmanager_v2/representations.rb,
lib/google/apis/deploymentmanager_v2/representations.rb
Overview
Represents an Operation resource. Google Compute Engine has three Operation
resources: * Global * Regional * Zonal You can use an operation resource to manage asynchronous API
requests. For more information, read Handling API responses. Operations can be
global, regional or zonal. - For global operations, use the globalOperations
resource. - For regional operations, use the regionOperations resource. -
For zonal operations, use the zoneOperations resource. For more information,
read Global, Regional, and Zonal Resources. Note that completed Operation
resources have a limited retention period.
Defined Under Namespace
Instance Attribute Summary collapse
-
#client_operation_id ⇒ String
[Output Only] The value of
requestIdif you provided it in the request. -
#creation_timestamp ⇒ String
[Deprecated] This field is deprecated.
-
#description ⇒ String
[Output Only] A textual description of the operation, which is set when the operation is created.
-
#end_time ⇒ String
[Output Only] The time that this operation was completed.
-
#error ⇒ Google::Apis::DeploymentmanagerV2::Operation::Error
[Output Only] If errors are generated during processing of the operation, this field will be populated.
-
#firewall_policy_rule_operation_metadata ⇒ Google::Apis::DeploymentmanagerV2::FirewallPolicyRuleOperationMetadata
Corresponds to the JSON property
firewallPolicyRuleOperationMetadata. -
#get_version_operation_metadata ⇒ Google::Apis::DeploymentmanagerV2::GetVersionOperationMetadata
Corresponds to the JSON property
getVersionOperationMetadata. -
#http_error_message ⇒ String
[Output Only] If the operation fails, this field contains the HTTP error message that was returned, such as
NOT FOUND. -
#http_error_status_code ⇒ Fixnum
[Output Only] If the operation fails, this field contains the HTTP error status code that was returned.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the operation.
-
#insert_time ⇒ String
[Output Only] The time that this operation was requested.
-
#instances_bulk_insert_operation_metadata ⇒ Google::Apis::DeploymentmanagerV2::InstancesBulkInsertOperationMetadata
Corresponds to the JSON property
instancesBulkInsertOperationMetadata. -
#kind ⇒ String
Output only.
-
#name ⇒ String
[Output Only] Name of the operation.
-
#operation_group_id ⇒ String
Output only.
-
#operation_type ⇒ String
[Output Only] The type of operation, such as
insert,update, ordelete, and so on. -
#progress ⇒ Fixnum
[Output Only] An optional progress indicator that ranges from 0 to 100.
-
#region ⇒ String
[Output Only] The URL of the region where the operation resides.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#self_link_with_id ⇒ String
Output only.
-
#set_autoscaler_link_operation_metadata ⇒ Google::Apis::DeploymentmanagerV2::SetAutoscalerLinkOperationMetadata
This field is used internally by the Autoscaler team and should not be promoted to "alpha/beta/v1".
-
#set_common_instance_metadata_operation_metadata ⇒ Google::Apis::DeploymentmanagerV2::SetCommonInstanceMetadataOperationMetadata
Output only.
-
#start_time ⇒ String
[Output Only] The time that this operation was started by the server.
-
#status ⇒ String
[Output Only] The status of the operation, which can be one of the following:
PENDING,RUNNING, orDONE. -
#status_message ⇒ String
[Output Only] An optional textual description of the current status of the operation.
-
#target_id ⇒ Fixnum
[Output Only] The unique target ID, which identifies a specific incarnation of the target resource.
-
#target_link ⇒ String
[Output Only] The URL of the resource that the operation modifies.
-
#user ⇒ String
[Output Only] User who requested the operation, for example:
user@example.comoralice_smith_identifier (global/workforcePools/example-com-us-employees). -
#warnings ⇒ Array<Google::Apis::DeploymentmanagerV2::Operation::Warning>
[Output Only] If warning messages are generated during processing of the operation, this field will be populated.
-
#zone ⇒ String
[Output Only] The URL of the zone where the operation resides.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Operation
constructor
A new instance of Operation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Operation
Returns a new instance of Operation.
1226 1227 1228 |
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1226 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_operation_id ⇒ String
[Output Only] The value of requestId if you provided it in the request. Not
present otherwise.
Corresponds to the JSON property clientOperationId
1051 1052 1053 |
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1051 def client_operation_id @client_operation_id end |
#creation_timestamp ⇒ String
[Deprecated] This field is deprecated.
Corresponds to the JSON property creationTimestamp
1056 1057 1058 |
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1056 def @creation_timestamp end |
#description ⇒ String
[Output Only] A textual description of the operation, which is set when the
operation is created.
Corresponds to the JSON property description
1062 1063 1064 |
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1062 def description @description end |
#end_time ⇒ String
[Output Only] The time that this operation was completed. This value is in
RFC3339 text format.
Corresponds to the JSON property endTime
1068 1069 1070 |
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1068 def end_time @end_time end |
#error ⇒ Google::Apis::DeploymentmanagerV2::Operation::Error
[Output Only] If errors are generated during processing of the operation, this
field will be populated.
Corresponds to the JSON property error
1074 1075 1076 |
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1074 def error @error end |
#firewall_policy_rule_operation_metadata ⇒ Google::Apis::DeploymentmanagerV2::FirewallPolicyRuleOperationMetadata
Corresponds to the JSON property firewallPolicyRuleOperationMetadata
1079 1080 1081 |
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1079 def @firewall_policy_rule_operation_metadata end |
#get_version_operation_metadata ⇒ Google::Apis::DeploymentmanagerV2::GetVersionOperationMetadata
Corresponds to the JSON property getVersionOperationMetadata
1084 1085 1086 |
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1084 def @get_version_operation_metadata end |
#http_error_message ⇒ String
[Output Only] If the operation fails, this field contains the HTTP error
message that was returned, such as NOT FOUND.
Corresponds to the JSON property httpErrorMessage
1090 1091 1092 |
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1090 def @http_error_message end |
#http_error_status_code ⇒ Fixnum
[Output Only] If the operation fails, this field contains the HTTP error
status code that was returned. For example, a 404 means the resource was not
found.
Corresponds to the JSON property httpErrorStatusCode
1097 1098 1099 |
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1097 def http_error_status_code @http_error_status_code end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the operation. This identifier is
defined by the server.
Corresponds to the JSON property id
1103 1104 1105 |
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1103 def id @id end |
#insert_time ⇒ String
[Output Only] The time that this operation was requested. This value is in
RFC3339 text format.
Corresponds to the JSON property insertTime
1109 1110 1111 |
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1109 def insert_time @insert_time end |
#instances_bulk_insert_operation_metadata ⇒ Google::Apis::DeploymentmanagerV2::InstancesBulkInsertOperationMetadata
Corresponds to the JSON property instancesBulkInsertOperationMetadata
1114 1115 1116 |
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1114 def @instances_bulk_insert_operation_metadata end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#operation
for Operation resources.
Corresponds to the JSON property kind
1120 1121 1122 |
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1120 def kind @kind end |
#name ⇒ String
[Output Only] Name of the operation.
Corresponds to the JSON property name
1125 1126 1127 |
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1125 def name @name end |
#operation_group_id ⇒ String
Output only. [Output Only] An ID that represents a group of operations, such
as when a group of operations results from a bulkInsert API request.
Corresponds to the JSON property operationGroupId
1131 1132 1133 |
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1131 def operation_group_id @operation_group_id end |
#operation_type ⇒ String
[Output Only] The type of operation, such as insert, update, or delete,
and so on.
Corresponds to the JSON property operationType
1137 1138 1139 |
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1137 def operation_type @operation_type end |
#progress ⇒ Fixnum
[Output Only] An optional progress indicator that ranges from 0 to 100. There
is no requirement that this be linear or support any granularity of operations.
This should not be used to guess when the operation will be complete. This
number should monotonically increase as the operation progresses.
Corresponds to the JSON property progress
1145 1146 1147 |
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1145 def progress @progress end |
#region ⇒ String
[Output Only] The URL of the region where the operation resides. Only
applicable when performing regional operations.
Corresponds to the JSON property region
1151 1152 1153 |
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1151 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
1156 1157 1158 |
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1156 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
1162 1163 1164 |
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1162 def self_link_with_id @self_link_with_id end |
#set_autoscaler_link_operation_metadata ⇒ Google::Apis::DeploymentmanagerV2::SetAutoscalerLinkOperationMetadata
This field is used internally by the Autoscaler team and should not be
promoted to "alpha/beta/v1".
Corresponds to the JSON property setAutoscalerLinkOperationMetadata
1168 1169 1170 |
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1168 def @set_autoscaler_link_operation_metadata end |
#set_common_instance_metadata_operation_metadata ⇒ Google::Apis::DeploymentmanagerV2::SetCommonInstanceMetadataOperationMetadata
Output only. [Output Only] If the operation is for projects.
setCommonInstanceMetadata, this field will contain information on all
underlying zonal actions and their state.
Corresponds to the JSON property setCommonInstanceMetadataOperationMetadata
1175 1176 1177 |
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1175 def @set_common_instance_metadata_operation_metadata end |
#start_time ⇒ String
[Output Only] The time that this operation was started by the server. This
value is in RFC3339 text format.
Corresponds to the JSON property startTime
1181 1182 1183 |
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1181 def start_time @start_time end |
#status ⇒ String
[Output Only] The status of the operation, which can be one of the following:
PENDING, RUNNING, or DONE.
Corresponds to the JSON property status
1187 1188 1189 |
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1187 def status @status end |
#status_message ⇒ String
[Output Only] An optional textual description of the current status of the
operation.
Corresponds to the JSON property statusMessage
1193 1194 1195 |
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1193 def @status_message end |
#target_id ⇒ Fixnum
[Output Only] The unique target ID, which identifies a specific incarnation of
the target resource.
Corresponds to the JSON property targetId
1199 1200 1201 |
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1199 def target_id @target_id end |
#target_link ⇒ String
[Output Only] The URL of the resource that the operation modifies. For
operations related to creating a snapshot, this points to the disk that the
snapshot was created from.
Corresponds to the JSON property targetLink
1206 1207 1208 |
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1206 def target_link @target_link end |
#user ⇒ String
[Output Only] User who requested the operation, for example: user@example.com
or alice_smith_identifier (global/workforcePools/example-com-us-employees).
Corresponds to the JSON property user
1212 1213 1214 |
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1212 def user @user end |
#warnings ⇒ Array<Google::Apis::DeploymentmanagerV2::Operation::Warning>
[Output Only] If warning messages are generated during processing of the
operation, this field will be populated.
Corresponds to the JSON property warnings
1218 1219 1220 |
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1218 def warnings @warnings end |
#zone ⇒ String
[Output Only] The URL of the zone where the operation resides. Only applicable
when performing per-zone operations.
Corresponds to the JSON property zone
1224 1225 1226 |
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1224 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 |
# File 'lib/google/apis/deploymentmanager_v2/classes.rb', line 1231 def update!(**args) @client_operation_id = args[:client_operation_id] if args.key?(:client_operation_id) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @firewall_policy_rule_operation_metadata = args[:firewall_policy_rule_operation_metadata] if args.key?(:firewall_policy_rule_operation_metadata) @get_version_operation_metadata = args[:get_version_operation_metadata] if args.key?(:get_version_operation_metadata) @http_error_message = args[:http_error_message] if args.key?(:http_error_message) @http_error_status_code = args[:http_error_status_code] if args.key?(:http_error_status_code) @id = args[:id] if args.key?(:id) @insert_time = args[:insert_time] if args.key?(:insert_time) @instances_bulk_insert_operation_metadata = args[:instances_bulk_insert_operation_metadata] if args.key?(:instances_bulk_insert_operation_metadata) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @operation_group_id = args[:operation_group_id] if args.key?(:operation_group_id) @operation_type = args[:operation_type] if args.key?(:operation_type) @progress = args[:progress] if args.key?(:progress) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @set_autoscaler_link_operation_metadata = args[:set_autoscaler_link_operation_metadata] if args.key?(:set_autoscaler_link_operation_metadata) @set_common_instance_metadata_operation_metadata = args[:set_common_instance_metadata_operation_metadata] if args.key?(:set_common_instance_metadata_operation_metadata) @start_time = args[:start_time] if args.key?(:start_time) @status = args[:status] if args.key?(:status) @status_message = args[:status_message] if args.key?(:status_message) @target_id = args[:target_id] if args.key?(:target_id) @target_link = args[:target_link] if args.key?(:target_link) @user = args[:user] if args.key?(:user) @warnings = args[:warnings] if args.key?(:warnings) @zone = args[:zone] if args.key?(:zone) end |